# imgmasks
Software project for Code / Astro 2021 Workshop — Briley Lewis, Ronald Lopez, Elizabeth Teng, Jason Williams. Code to make arbitrary circular or elliptical masks for an image in Python 

Documentation at https://elliptical-mask.readthedocs.io/en/latest/index.html

![Read the Docs](https://img.shields.io/readthedocs/elliptical-mask)
![GitHub all releases](https://img.shields.io/github/downloads/briley-lewis/elliptical-mask/total)
![GitHub contributors](https://img.shields.io/github/contributors/briley-lewis/elliptical-mask)
![GitHub last commit](https://img.shields.io/github/last-commit/briley-lewis/elliptical-mask)
![GitHub language count](https://img.shields.io/github/languages/count/briley-lewis/elliptical-mask)
![GitHub](https://img.shields.io/github/license/briley-lewis/elliptical-mask)
[![DOI](https://zenodo.org/badge/379351745.svg)](https://zenodo.org/badge/latestdoi/379351745)

install me with `pip install imgmasks` :)
